import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:kloktun_helper/widgets/gap.dart';

Future<String?> showEnterCodeModal({
  
  required BuildContext context,
  required Widget title,
  required Widget description,
  required String buttonText,

  InputDecoration? decoration

}) async {

  String code = await showModalBottomSheet(
    
    context: context,

    isScrollControlled: true,

    builder: (context){
      return EnterCode(
        title: title,
        description: description,
        buttonText: buttonText,
        decoration: decoration,
      );
    }
  );

  return code;

}

class EnterCode extends StatefulWidget {

  Widget title;
  Widget description;
  String buttonText;
  
  InputDecoration? decoration;



  EnterCode({
    Key? key,
    
    required this.title,
    required this.description,
    required this.buttonText,

    this.decoration

  }) : super(key: key);

  @override
  _EnterCodeState createState() => _EnterCodeState();
}

class _EnterCodeState extends State<EnterCode> {

  late TextEditingController _textEditingController;

  @override
  void initState() { 
    super.initState();
    
    _textEditingController = TextEditingController();

  }

  _submit(){

    var value = _textEditingController.text;

    if(value.isEmpty){
      Navigator.of(context).pop();
      return;
    }

    Navigator.of(context).pop(value);

  }


  Widget _buildForm(){

    return Column(

      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,

      mainAxisSize: MainAxisSize.min,

      children: [

        DefaultTextStyle(
          child: widget.title,
          style: const TextStyle(
            fontSize: 20,
            fontWeight: FontWeight.w500
          )
        ),

        const VGap(15),

        DefaultTextStyle(
          child: widget.description, 
          style: const TextStyle(
            fontSize: 14,
          )
        ),

        SizedBox(height: 20.sp),

        TextField(

          controller: _textEditingController,

          autofocus: true,

          keyboardType: TextInputType.number,

          onSubmitted: (value){

            _submit();

          },
          
          decoration: widget.decoration ?? InputDecoration(
            hintText: "1234",
            border: OutlineInputBorder(),
          )

        ),

        SizedBox(height: 15.sp),

        Container(
          width: double.infinity,
          child: ElevatedButton(
            onPressed: (){

              _submit();

            },
            child: Text(widget.buttonText)
          )
        ),

        Container(
          height: MediaQuery.of(context).viewInsets.bottom,
        )
      ],

    );

  }
  
  @override
  Widget build(BuildContext context) {

    double paddingBottom = MediaQuery.of(context).padding.bottom;

    return Container(

      padding: EdgeInsets.all(15.sp).copyWith(bottom: paddingBottom + 15.sp),
      child: _buildForm(),

    );
  }
}